@@ -3,7 +3,7 @@ var indexSectionsWithContent =
   0: "acdeikmprstuw~",
   1: "w",
   2: "aimprstuw~",
-  3: "r"
+  3: "cdekrsw"
 };
 
 var indexSectionNames =
